Random assortment of functions that are used internally to write plugins.
Functions
- calc_
right_ whitespace_ with_ tabstops - Calculate trailing whitespace with total length of
indent. - cut_
right_ whitespace_ with_ tabstops - Returns trailing whitespace with total length of
indent. - escape_
html - Escape
< > " &with corresponding HTML entities; - find_
indent_ of - Calculate the number of spaces from
posto the first non-space character or EOL. - get_
entity_ from_ str - Check if “&xxxx;” string is a valid HTML entity, return character it represents.
- is_
punct_ char - Checks whether a given character should count as punctuation
- is_
valid_ entity_ code - Return true if a
codeyou got from&#xHHHH;entity is a valid charcode. - normalize_
reference - Unicode case folding and space normalization, used for reference labels.
- rfind_
and_ count - Count number of characters since the last occurrence of
char. - unescape_
all - Unescape both entities (
" -> ") and backslash escapes (\" -> ").